function psd_speckle, cube, rho
;
; Spectral density computation of speckle images from a
; reference star (PSF) and speckle images from a binary
; star of separation rho (along x)
;
; cube: reference star speckles
; rho : binary separation [px]
; use:
; rho = 10L
; dsp = psd_speckle(cube, rho)
;
; Marcel Carbillet (marcel.carbillet@unice.fr), Feb. 2018
;
dim=(size(cube))[2]
nim=(size(cube))[3]

dsp_sp=fltarr(dim,dim)
for i=0, nim-1L do dsp_sp+=(abs(fft(cube[*,*,i])))^2
dsp_sp=shift(dsp_sp, dim/2, dim/2)

double=cube+shift(cube, rho, 0, 0)
dsp_db=fltarr(dim,dim)
for i=0, nim-1L do dsp_db+=(abs(fft(double[*,*,i])))^2
dsp_db=shift(dsp_db, dim/2, dim/2)

return, [dsp_sp, dsp_db]
end